package Bundle::ExCore::Perl5018;

use strict;

our $VERSION = '0.003';

1;

__END__

=head1 NAME

Bundle::ExCore::Perl5018 - modules deprecated in perl v5.018

=head1 SYNOPSIS

  perl -MCPAN -e "install Bundle::ExCore::Perl5018"

=head1 CONTENTS

Archive::Extract

B::Lint

CPANPLUS

Devel::InnerPackage

File::CheckTree

Log::Message

Module::Pluggable

Object::Accessor

Pod::LaTeX

Term::UI

Text::Soundex

=head1 DESCRIPTION

This part of Bundle::ExCore contains modules that were deprecated as
core modules in perl v5.018.

=head1 SEE ALSO

L<Bundle::ExCore>

=head1 AUTHOR

Martin Becker, E<lt>mhasch@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2015 by Martin Becker.  All rights reserved.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.20.2 or,
at your option, any later version of Perl 5 you may have available.

=cut
